<template>
  <j-modal
    :title="title"
    :width="width"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form-model
        ref="form"
        :model="model"
        :rules="validatorRules"
      >
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-model-item
              label="意见或原因"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="remark"
            >
            <a-textarea v-model="model.remark" rows="4" placeholder="意见或原因" />
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>
<script>
import { httpAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'
import pick from 'lodash.pick'
import { postAction, requestPut, getAction } from '@/api/manage'
import { duplicateCheck } from '@/api/api'
import moment from 'moment'
import { JVxeTableModelMixin } from '@/mixins/JVxeTableModelMixin.js'
import { JVXETypes } from '@/components/jeecg/JVxeTable'
export default {
  name: "NodeModel",
  mixins: [JVxeTableModelMixin],
  components: {
    validateDuplicateValue,
  },
  props: {
    disableSubmit: {
      type: Boolean,
      default: false,
      required: false
    },
    caytegoryParam: {
      type: String,
      default: '',
      required: false
    }
  },
  data() {
    return {
      title: "操作",
      width: 1500,
      visible: false,
      model: {
      },
      labelCol: {
          xs: { span: 24 },
          sm: { span: 5 },
      },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 16 },
      },

      confirmLoading: false,
      validatorRules: {
        remark: [
          { min: 0, max: 100, message: '长度不超过 100 个字符', trigger: 'blur' },
        ],
      },
      url: {
        next: "/eam/stream/next",
        last: "/eam/stream/last",
      },
    }
  },
  created() {
    //备份model原始值
    this.initOptions();
    this.modelDefault = JSON.parse(JSON.stringify(this.model));
  },
  methods: {
    add() {
      this
      this.edit(this.modelDefault);
    },
    edit(record) {
      this.model = Object.assign({}, record);
      this.visible = true;
    },
    close() {
      this.$emit('close');
      this.visible = false;
      this.$refs.form.clearValidate();
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (this.model.opType=='next') {
            httpurl += this.url.next;
          } else {
            httpurl += this.url.last;
          } 
          method = 'post';
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        } else {
          return false
        }
      })
    },
    handleCancel() {
      this.close()
    },
  },
  computed: {
    formDisabled() {
      return this.disableSubmit
    },
  },
}
</script>